from lclazy import lazy_re_compile
from subprocess import run
from .environment import is_drawbridge_os

RPM_VERSION_REGEX = lazy_re_compile(r'-([\d\.]*\d*-\d*)')


def package_version(name: str) -> str:
    """
    Get version of installed DEB or RPM package.

    # rpm -q pdns-recursor = pdns-recursor-4.2.1-1pdns.el6.x86_64
    >>> package_version('pdns-recursor')
    4.2.1-1
    # rpm -q redwood = redwood-1.1-42.x86_64
    >>> package_version('redwood')
    1.1-42
    # rpm -q logcabin = logcabin-1.9-715.noarch
    >>> package_version('redwood')
    1.9-715
    """
    if is_drawbridge_os():
        try:
            query = run(
                ['apt', 'show', name],
                capture_output=True,
            ).stdout.decode().strip().split('\n')[0:3]
            package_details = dict([d.split(':') for d in query])
            return package_details['Version'].strip()
        except (IndexError, KeyError, ValueError):
            pass
        return ''

    try:
        query = run(['rpm', '-q', name], capture_output=True).stdout.decode()
        if rpm := RPM_VERSION_REGEX.search(query):
            return rpm.group(1)
    except (AttributeError, IndexError, TypeError):
        pass

    return ''


__all__ = (
    'package_version',
)
